==> zio-aws-keyspaces_2.13-7.28.29.10-sources.jar: zio/aws/keyspaces/model/package.scala <==
package zio.aws.keyspaces
import zio.prelude.Subtype
import zio.aws.keyspaces.model.primitives.Region
import java.time.Instant
import zio.aws.keyspaces.model.primitives.ARN.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ARN extends zio.prelude.Subtype[String]
    type ARN = zio.aws.keyspaces.model.primitives.ARN.Type
    type BooleanObject = Boolean
    object CapacityUnits extends zio.prelude.Subtype[Long]
    type CapacityUnits = zio.aws.keyspaces.model.primitives.CapacityUnits.Type
    object DefaultTimeToLive extends zio.prelude.Subtype[Int]
    type DefaultTimeToLive =
      zio.aws.keyspaces.model.primitives.DefaultTimeToLive.Type
    type DoubleObject = Double
    type GenericString = String
    type IntegerObject = Int
    object KeyspaceName extends zio.prelude.Subtype[String]
    type KeyspaceName = zio.aws.keyspaces.model.primitives.KeyspaceName.Type
    object KmsKeyARN extends zio.prelude.Subtype[String]
    type KmsKeyARN = zio.aws.keyspaces.model.primitives.KmsKeyARN.Type
    object MaxResults extends zio.prelude.Subtype[Int]
    type MaxResults = zio.aws.keyspaces.model.primitives.MaxResults.Type
    object NextToken extends zio.prelude.Subtype[String]
    type NextToken = zio.aws.keyspaces.model.primitives.NextToken.Type
    object Region extends zio.prelude.Subtype[String]
    type Region = zio.aws.keyspaces.model.primitives.Region.Type
    object TableName extends zio.prelude.Subtype[String]
    type TableName = zio.aws.keyspaces.model.primitives.TableName.Type
    object TagKey extends zio.prelude.Subtype[String]
    type TagKey = zio.aws.keyspaces.model.primitives.TagKey.Type
    object TagValue extends zio.prelude.Subtype[String]
    type TagValue = zio.aws.keyspaces.model.primitives.TagValue.Type
    object Timestamp extends zio.prelude.Subtype[Instant]
    type Timestamp = zio.aws.keyspaces.model.primitives.Timestamp.Type
  }
  type ClusteringKeyList = List[zio.aws.keyspaces.model.ClusteringKey]
  type ColumnDefinitionList = List[zio.aws.keyspaces.model.ColumnDefinition]
  type KeyspaceSummaryList = List[zio.aws.keyspaces.model.KeyspaceSummary]
  type PartitionKeyList = List[zio.aws.keyspaces.model.PartitionKey]
  type RegionList = List[Region]
  type ReplicaAutoScalingSpecificationList =
    List[zio.aws.keyspaces.model.ReplicaAutoScalingSpecification]
  type ReplicaSpecificationList =
    List[zio.aws.keyspaces.model.ReplicaSpecification]
  type ReplicaSpecificationSummaryList =
    List[zio.aws.keyspaces.model.ReplicaSpecificationSummary]
  type StaticColumnList = List[zio.aws.keyspaces.model.StaticColumn]
  type TableSummaryList = List[zio.aws.keyspaces.model.TableSummary]
  type TagList = List[zio.aws.keyspaces.model.Tag]
}

==> zio-aws-keyspaces_3-5.17.161.2-sources.jar: zio/aws/keyspaces/model/package.scala <==
package zio.aws.keyspaces
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.keyspaces.model.primitives.ARN.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ARN extends Subtype[String]
    type ARN = zio.aws.keyspaces.model.primitives.ARN.Type
    object CapacityUnits extends Subtype[Long]
    type CapacityUnits = zio.aws.keyspaces.model.primitives.CapacityUnits.Type
    object DefaultTimeToLive extends Subtype[Int]
    type DefaultTimeToLive =
      zio.aws.keyspaces.model.primitives.DefaultTimeToLive.Type
    type GenericString = String
    object KeyspaceName extends Subtype[String]
    type KeyspaceName = zio.aws.keyspaces.model.primitives.KeyspaceName.Type
    object KmsKeyARN extends Subtype[String]
    type KmsKeyARN = zio.aws.keyspaces.model.primitives.KmsKeyARN.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.keyspaces.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.keyspaces.model.primitives.NextToken.Type
    object TableName extends Subtype[String]
    type TableName = zio.aws.keyspaces.model.primitives.TableName.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.keyspaces.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.keyspaces.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.keyspaces.model.primitives.Timestamp.Type
  }
  type ClusteringKeyList = List[zio.aws.keyspaces.model.ClusteringKey]
  type ColumnDefinitionList = List[zio.aws.keyspaces.model.ColumnDefinition]
  type KeyspaceSummaryList = List[zio.aws.keyspaces.model.KeyspaceSummary]
  type PartitionKeyList = List[zio.aws.keyspaces.model.PartitionKey]
  type StaticColumnList = List[zio.aws.keyspaces.model.StaticColumn]
  type TableSummaryList = List[zio.aws.keyspaces.model.TableSummary]
  type TagList = List[zio.aws.keyspaces.model.Tag]
}
